@@ -47,6 +47,10 @@ if Path(STATIC_FILE_DEFAULT_PATH).exists():
 if known_persons:
     log.debug(f"loaded static data for {', '.join(known_persons.keys())}")
 
+# we have discovered the city clerk accidentally entered Daniel Strauss
+# instead of the correct Dan Strauss for a few events
+PERSON_ALIASES = {"Dan Strauss": set(["Daniel Strauss"])}
+
 ###############################################################################
 
 
@@ -77,6 +81,7 @@ class SeattleScraper(LegistarScraper):
                 "Pursuant to Washington State",
             ],
             known_persons=known_persons,
+            person_aliases=PERSON_ALIASES,
         )
 
     def parse_content_uris(
@@ -131,9 +136,16 @@ class SeattleScraper(LegistarScraper):
         # ...
 
         # entire script tag text that has the video player setup call
-        video_script_text = soup.find(
+        video_script_block = soup.find(
             "script", text=re.compile(r"playerInstance\.setup")
-        ).string
+        )
+        if not video_script_block:
+            log.warning(
+                f"Couldn't find 'playerInstance.setup()' block on {video_page_url}.\n"
+                "seattlechannel.org may have changed their video page html"
+            )
+            return []
+        video_script_text = video_script_block.string
 
         # halt if event date not in video's idstring
         # likely means some change on video web page source / script
